@@ -6,8 +6,8 @@
 """
 
 __author__ = "James Turk (jturk@sunlightfoundation.com)"
-__version__ = "1.1.0"
-__copyright__ = "Copyright (c) 2010 Sunlight Labs"
+__version__ = "1.1.1"
+__copyright__ = "Copyright (c) 2012 Sunlight Labs"
 __license__ = "BSD"
 
 import sys
@@ -27,6 +27,10 @@ try:
 except ImportError:
     import simplejson as json
 
+import warnings
+warnings.warn('python-openstates is deprecated in favor of python-sunlight\n'
+              'http://python-sunlight.readthedocs.org/', DeprecationWarning)
+
 class SunlightApiError(Exception):
     """ Exception for Sunlight API errors """
 
